@@ -493,11 +493,9 @@ class DataRange1d(DataRange):
     end = Float
 
 
-class FactorRange(DataRange):
+class FactorRange(PlotObject):
     """ Represents a range in a categorical dimension """
-    sources = List(ColumnsRef, has_ref=True)
-    values = List
-    columns = List
+    factors = List
 
 class Glyph(PlotObject):
 
@@ -562,6 +560,8 @@ class Glyph(PlotObject):
 
 
 class Plot(PlotObject):
+    """ Object representing a plot, containing glyphs, guides, annotations.
+    """
 
     data_sources = List
     title = String("Bokeh Plot")
@@ -572,10 +572,6 @@ class Plot(PlotObject):
     title = String('')
     outline_props = Include(LineProps, prefix="outline")
 
-    # We shouldn't need to create mappers manually on the Python side
-    #xmapper = Instance(LinearMapper)
-    #ymapper = Instance(LinearMapper)
-    #mapper = Instance(GridMapper)
 
     # A list of all renderers on this plot; this includes guides as well
     # as glyph renderers
@@ -742,8 +738,8 @@ class GuideRenderer(PlotObject):
             if self not in self.plot.renderers:
                 self.plot.renderers.append(self)
 
-class LinearAxis(GuideRenderer):
-    type = String("linear_axis")
+class Axis(GuideRenderer):
+    type = String("axis")
 
     dimension = Int(0)
     location = Either(String('min'), Float)
@@ -764,6 +760,12 @@ class LinearAxis(GuideRenderer):
     major_tick_in = Int
     major_tick_out = Int
 
+class LinearAxis(Axis):
+    type = String("linear_axis")
+
+class CategoricalAxis(Axis):
+    type = String("categorical_axis")
+
 class DatetimeAxis(LinearAxis):
     type = String("datetime_axis")
     axis_label = String("date")
@@ -823,6 +825,10 @@ class BoxSelectionOverlay(PlotObject):
     __view_model__ = 'BoxSelection'
     tool = Instance(has_ref=True)
 
+class HoverTool(PlotObject):
+    renderers = List(has_ref=True)
+    tooltips = Dict()
+
 class Legend(PlotObject):
     plot = Instance(Plot, has_ref=True)
     orientation = Enum("top_right", "top_left", "bottom_left", "bottom_right")
